(function($) {
	
	$.fn.heatCalculator = function(options) {
		
		var defaults = {
			isProMode  : false,
			area       : 200,
			heatLoss   : 100,

			insulation:
				[
					[ "labi siltināta privātmāja"                       , 100 ],
					[ "vidēji siltināta privātmāja"                     , 130 ],
					[ "slikti siltināja privātmāja"                     , 180 ],
					[ "jauna, pēc standartiem celta daudzdzīvokļu māja" ,  80 ],
					[ "siltināta daudzdzīvokļu māja"                    , 100 ],
					[ "daudzdzīvokļu māja"                              , 120 ]
				],

			data: 
				[
					[ "Granulas"                                 , 0.85 , "1 tonna"   , 4880.00 , 160.00   ],
					[ "Malka (25% mitra)"                        , 0.72 , "1 m&sup3;" , 2110.00 ,  40.00   ],
					[ "Dabas gāze"                               , 0.90 , "1 m&sup3;" ,    8.84 ,   0.59   ],
					[ "Sašķidrinātā gāze"                        , 0.90 , "1 m&sup3;" ,   31.40 ,   2.61   ],
					[ "Kurināmā degviela"                        , 0.90 , "1 litrs"   ,    9.83 ,   1.07   ],
					[ "Elektroapkure"                            , 0.97 , "1 kWh"     ,    1.00 ,   0.160 ],
					[ "Zemes siltumsūknis (radiatori)"           , 4.00 , "1 kWh"     ,    1.00 ,   0.160 ],
					[ "Zemes siltumsūknis (siltās grīdas)"       , 4.50 , "1 kWh"     ,    1.00 ,   0.160 ],
					[ "Siltumsūknis gaiss/ūdens (radiatori)"     , 3.20 , "1 kWh"     ,    1.00 ,   0.160 ],
					[ "Siltumsūknis gaiss/ūdens (siltās grīdas)" , 3.80 , "1 kWh"     ,    1.00 ,   0.160 ],
					[ "Siltumsūknis    (siltie/aukstie griesti)" , 5.50 , "1 kWh"     ,    1.00 ,   0.160 ]
				],
				
			columnWidths:
				[ 300, 90, 90, 90, 90, 100, 100 ]
		};
		
		var options = $.extend(defaults, options);
		var form = $(this);
		
		createHcForm();
		calculate();
		
		/**
		 * Creates the Heat Calculator form.
		 */
		function createHcForm()
		{
			form.empty();
			
			var labelSpan = $("<span>").attr("class", "label");
			var ctrlSpan  = $("<span>").attr("class", "ctrl");
			
			var mode = $("<a>").attr("href", "#").html("Pārslēgties uz profesionālo kalkulatoru");
			if (options.isProMode == true)
			{
				mode.html("Pārslēgties uz parasto kalkulatoru").attr("class", "pro");
			}
			mode.click(function() {
				$(this).toggleClass("pro");
				options.isProMode = $(this).hasClass("pro");
				createHcForm();
				calculate();
			});

			var ctrl1 = $("<div>").
				append(labelSpan.clone().html(mode)).
				append(ctrlSpan.clone().html("&nbsp;"));
			
			var ctrl2 = $("<div>").
				append(labelSpan.clone().html("Mājas platība (m&sup2;):")).
				append(ctrlSpan.clone().html($("<input>").
					attr("type", "text").
					attr("id", "hcarea").
					attr("value", options.area)));
			
			var insulationCombo = $("<select>").attr("id", "hcinsulation");
			for (var i = 0; i < options.insulation.length; i++)
			{
				insulationCombo.append(
					$("<option>").
					attr("value", options.insulation[i][1]).
					html(options.insulation[i][0]));
			}
			insulationCombo.change(function() {
				$("#hcheatloss").val($(this).val());
			});
			
			var ctrl3 = $("<div>").
				append(labelSpan.clone().html("Mājas siltinājums:")).
				append(ctrlSpan.clone().html(insulationCombo));
			
			var ctrl4 = $("<div>").
				append(labelSpan.clone().html("Siltumenerģijas zudumi (kWh/m&sup2;/gadā):")).
				append(ctrlSpan.clone().html($("<input>").
					attr("type", "text").
					attr("id", "hcheatloss").
					attr("value", options.heatLoss)));
			
			var ctrl5 = $("<div>").
				append(labelSpan.clone().html("Siltumenerģijas nepieciešamība (kWh):")).
				append(ctrlSpan.clone().html($("<span>").
					attr("id", "hcnecessity").
					html("-")));
			
			var col1 = $("<col>").attr("width", options.columnWidths[0]);
			var col2 = $("<col>").attr("width", options.columnWidths[1]);
			var col3 = $("<col>").attr("width", options.columnWidths[2]);
			var col4 = $("<col>").attr("width", options.columnWidths[3]);
			var col5 = $("<col>").attr("width", options.columnWidths[4]);
			var col6 = $("<col>").attr("width", options.columnWidths[5]);
			var col7 = $("<col>").attr("width", options.columnWidths[6]);
			
			var columns = $("<colgroup>").
				append(col1).append(col2).append(col3).append(col4).
				append(col5).append(col6).append(col7);
			
			var table = $("<table>").attr("id", "hctable").
				append(columns).
				append($("<thead>").html($("<tr>").
				append($("<th>").html("Apkures veids")).
				append($("<th>").html("Lietderības koeficients")).
				append($("<th>").html("Vienība")).
				append($("<th>").html("Enerģija no vienības, kWh")).
				append($("<th>").html("Cena par vienību, EUR")).
				append($("<th>").html("Daudzums gadā")).
				append($("<th>").html("Gada izmaksas, EUR")))).
				append($("<tbody>"));
			
			form.append(ctrl1).append(ctrl2).append(ctrl3).append(ctrl4).append(ctrl5).append(table);
			
			$("#hcarea").keyup(function() { calculate(); });
			$("#hcinsulation").change(function() { calculate(); });
			$("#hcheatloss").keyup(function() { calculate(); });
			
			if (options.isProMode == true)
			{
				$("#hcinsulation").parent().parent().css("display", "none");
				$('#hcheatloss').parent().parent().css("display", "block");
			}
			else
			{
				$("#hcinsulation").parent().parent().css("display", "block");
				$('#hcheatloss').parent().parent().css("display", "none");
			}			
		}
		
		/**
		 * Does actual calculations.
		 */
		function calculate()
		{
			options.area     = $("#hcarea").val();
			options.heatLoss = $("#hcheatloss").val();
			
			var necessity = options.area * options.heatLoss;
			$("#hcnecessity").html(necessity);
			
			$("#hctable tbody").empty();
			for (var i = 0; i < options.data.length; i++)
			{
				var ammount = necessity / options.data[i][1] / options.data[i][3];
				var cost    = ammount * options.data[i][4]; 
				
				var coeff;
				if (options.isProMode == true)
				{
					coeff = $('<input>').
						attr('type', 'text').
						attr('id', 'hccoeff' + i).
						attr('value', options.data[i][1].toFixed(2)).
						change(function() {
							var id = parseInt($(this).attr('id').substr(7, 2));
							options.data[id][1] = parseFloat($(this).val());
							calculate();
						});
				}
				else
				{
					coeff = $('<span>').html(options.data[i][1].toFixed(2));
				}
				
				var price;
				var floatingpoint;
				if (options.isProMode == true)
				{
					floatingpoint = options.data[i][4] > 0.11 ? 2 : 3;
				
					price = $('<input>').
						attr('type', 'text').
						attr('id', 'hcprice' + i).
						attr('value', options.data[i][4].toFixed(floatingpoint)).
						change(function() {
							var id = parseInt($(this).attr("id").substr(7, 2));
							options.data[id][4] = parseFloat($(this).val());
							calculate();
						});
				}
				else
				{
					floatingpoint = options.data[i][4] > 0.11 ? 2 : 3;
					price = $('<span>').html(options.data[i][4].toFixed(floatingpoint));
				}
				
				var row = $("<tr>").
					append($("<td>").html(options.data[i][0])).
					append($("<td>").html(coeff)).
					append($("<td>").html(options.data[i][2])).
					append($("<td>").html(options.data[i][3].toFixed(2))).
					append($("<td>").html(price)).
					append($("<td>").html(ammount.toFixed(2))).
					append($("<td>").html($("<strong>").html(cost.toFixed(2))));
				$("#hctable tbody").append(row);
			}
		}
	};

})(jQuery);